<?php
/**
 * @author Zoltán Zvara
 * @copyright Zoltán Zvara, 2014
 * @package Control
 * @version 1.0
 */
namespace Arylium\Control;

use Arylium\Control\Exception;

/**
 * Collects request types.
 */
class Query
{
    const Create = "create";
    const Read = "read";
    const Update = "update";
    const Delete = "delete";
    const Search = "search";
}

/**
 * Request entities.
 */
class Caller
{
    const Regular = 0;
    const Asynchronous = 1;
}

/**
 * Used to convert not set data to NULL.
 */
abstract class Request
{
    const POST = 1;
    const GET = 2;
    const REQUEST = 3;

    /**
     * Gets request parameter.
     * @param string $name Key, name of data.
     * @param integer $type Type of the data: POST, GET, REQUEST.
     * @throws Exception
     * @return mixed
     */
    public static function getParameter($name, $type = self::REQUEST)
    {
        switch ($type) {
            case self::POST:
                if (isset($_POST[$name])) {
                    return $_POST[$name];
                } else {
                    return NULL;
                }
            case self::GET:
                if (isset($_GET[$name])) {
                    return $_GET[$name];
                } else {
                    return NULL;
                }
            case self::REQUEST:
                if (isset($_REQUEST[$name])) {
                    return $_REQUEST[$name];
                } else {
                    return NULL;
                }
            default:
                throw new Exception();
        }
    }

    /**
     * Gets the requesting-entity.
     * @returns integer
     */
    public static function getCaller()
    {
        $headers = self::getHeaders();
        if (!isset($headers["X-Requested-With"])) {
            return Caller::Regular;
        }
        if ($headers["X-Requested-With"] == "XMLHttpRequest") {
            return Caller::Asynchronous;
        } else {
            return Caller::Regular;
        }
    }

    /**
     * Fetches the HTTP headers and collects them.
     * @return Array
     */
    protected static function getHeaders()
    {
        $headers = array();
        foreach ($_SERVER as $key => $value) {
            if (strpos($key, 'HTTP_') === 0) {
                $headers[str_replace(' ', '-', ucwords(str_replace('_', ' ', strtolower(substr($key, 5)))))] = $value;
            }
        }
        return $headers;
    }

    /**
     * Is the request an AJAX call?
     * @returns boolean
     */
    public static function isAsynchronous()
    {
        return (self::getCaller() == Caller::Asynchronous);
    }
}