<?php
/**
 * @author Zoltán Zvara
 * @copyright Zoltán Zvara, 2014
 * @package Core
 */
namespace Arylium;
/**
 * Settings loaded from an INI file.
 * @var Array $Settings
 */
$Settings = parse_ini_file("settings.ini", TRUE);

/**
 * Class represents a unique, essential component in the framework.
 * It loads the component specific settings.
 * @package Arylium
 */
abstract class Component{
    /**
     * Holds the component specific settings.
     * @var Array
     */
    protected $Settings = [];

    /**
     * Constructs the component by initializing its settings.
     * @returns Component
     */
    public function __construct(){
        $this->initialize();
    }

    /**
     * Loads the settings.
     */
    protected function initialize(){
        global $Settings;

        $this->Settings = &$Settings;

        $class_name = explode("\\", static::class);
        $class_name = array_pop($class_name);

        if(array_key_exists($class_name, $this->Settings)){
            $this->Settings = &$Settings[$class_name];
        }
    }
}

include_once 'model/model.inc';
include_once 'view/view.inc';

include_once 'control/redirect.inc';
include_once 'control/request.inc';
include_once 'control/router.inc';
include_once 'control/control.inc';
include_once 'control/site.inc';